@@ -7,11 +7,15 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
 
-0 <> 0 # Python 3.x not supported! Use 2.6+ instead.
-
 import os
 import sys
 
+if sys.version_info[0] != 2:
+    try:
+        os.execvp("python2", ["python"] + sys.argv)
+    except OSError:
+        pass
+
 import quodlibet
 from quodlibet import app
 from quodlibet import util
