@@ -13,11 +13,19 @@
 
 import sys
 import os
+
+if sys.version_info[0] != 2:
+    try:
+        os.execvp("python2", ["python"] + sys.argv)
+    except OSError:
+        pass
+
 import string
 import re
+import shutil
 from optparse import OptionParser
 
-from quodlibet.formats import MusicFile
+from quodlibet.formats import MusicFile, EmbeddedImage
 from quodlibet import config
 from quodlibet import const
 from quodlibet import parse
@@ -483,15 +491,133 @@ class InfoCommand(Command):
             print_terse_table(tags, nicks, order)
 
 
-class ImageExtractCommand(Command):
-    NAME = "image-extract"
-    DESCRIPTION = _("Extract embedded images")
-    USAGE = "<file> [<dest-name>]"
+class ImageSetCommand(Command):
+    NAME = "image-set"
+    DESCRIPTION = _("Set the provided image as primary embedded image and "
+                    "remove all other embedded images")
+    USAGE = "<image-file> <file> [<files>]"
+
+    def _execute(self, options, args):
+        if len(args) < 2:
+            raise CommandError(_("Not enough arguments"))
+
+        image_path = args[0]
+        paths = args[1:]
+
+        image = EmbeddedImage.from_path(image_path)
+        if not image:
+            raise CommandError(_("Failed to load image file: %r") % image_path)
+
+        songs = [self.load_song(p) for p in paths]
+
+        for song in songs:
+            if not song.can_change_images:
+                raise CommandError(
+                    _("Image editing not supported for %(file_name)s "
+                      "(%(file_format)s)") % {
+                      "file_name": song("~filename"),
+                      "file_format": song("~format")
+                    })
+
+        for song in songs:
+            song.set_image(image)
+
+
+class ImageClearCommand(Command):
+    NAME = "image-clear"
+    DESCRIPTION = _("Remove all embedded images")
+    USAGE = "<file> [<files>]"
 
     def _execute(self, options, args):
         if len(args) < 1:
             raise CommandError(_("Not enough arguments"))
 
+        paths = args
+        songs = [self.load_song(p) for p in paths]
+
+        for song in songs:
+            if not song.can_change_images:
+                raise CommandError(
+                    _("Image editing not supported for %(file_name)s "
+                      "(%(file_format)s)") % {
+                      "file_name": song("~filename"),
+                      "file_format": song("~format")
+                    })
+
+        for song in songs:
+            song.clear_images()
+
+
+class ImageExtractCommand(Command):
+    NAME = "image-extract"
+    DESCRIPTION = (
+        _("Extract embedded images to %(filepath)s") % {
+            "filepath": "<destination>/<filename>-<index>.(jpeg|png|..)"
+        }
+    )
+    USAGE = "[--dry-run] [--primary] [-d <destination>] <file> [<files>]"
+
+    def _add_options(self, p):
+        p.add_option("--dry-run", action="store_true",
+                     help="don't save images")
+        p.add_option("--primary", action="store_true",
+                     help="only extract the primary image")
+        p.add_option("-d", "--destination", action="store", type="string",
+                     help=_("Path to where the images will be saved to "
+                            "(defaults to the working directory)"))
+
+    def _execute(self, options, args):
+        if len(args) < 1:
+            raise CommandError(_("Not enough arguments"))
+
+        # dry run implies verbose
+        if options.dry_run:
+            self.verbose = True
+
+        paths = args
+        for path in paths:
+            song = self.load_song(path)
+
+            # get the primary one or all of them
+            if options.primary:
+                image = song.get_primary_image()
+                images = [image] if image else []
+            else:
+                images = song.get_images()
+
+            self.log("Images for %r: %r" % (path, images))
+
+            if not images:
+                continue
+
+            # get the basename from the song without the extension
+            basename = os.path.basename(path)
+            name = os.path.splitext(basename)[0]
+
+            # at least two places, but same length for all images
+            number_pattern = "%%0%dd" % (max(2, len(images) - 1))
+
+            for i, image in enumerate(images):
+                # get a appropriate file extension or use fallback
+                extensions = image.extensions
+                ext = extensions[0] if extensions else ".image"
+
+                if options.primary:
+                    # mysong.mp3 -> mysong.jpeg
+                    filename = "%s.%s" % (name, ext)
+                else:
+                    # mysong.mp3 -> mysong-00.jpeg
+                    pattern = "%s-" + number_pattern + ".%s"
+                    filename = pattern % (name, i, ext)
+
+                if options.destination is not None:
+                    filename = os.path.join(options.destination, filename)
+
+                self.log("Saving image %r" % filename)
+                if not options.dry_run:
+                    with open(filename, "wb") as h:
+                        shutil.copyfileobj(image.file, h)
+
 
 class RenameCommand(Command):
     NAME = "rename"
@@ -564,8 +690,15 @@ class PrintCommand(Command):
             raise CommandError("Invalid pattern: %r" % pattern)
 
         paths = args
+        error = False
         for path in paths:
-            print_(pattern % self.load_song(path))
+            try:
+                print_(pattern % self.load_song(path))
+            except CommandError:
+                error = True
+
+        if error:
+            raise CommandError("One or more files failed to load.")
 
 
 class HelpCommand(Command):
@@ -750,7 +883,7 @@ def run(argv=sys.argv):
             cmd = command(options)
             try:
                 cmd.execute(argv[offset + 1:])
-            except CommandError, e:
+            except CommandError as e:
                 print_("%s: %s" % (command.NAME, e), sys.stderr)
                 return 1
             break
@@ -764,11 +897,12 @@ def run(argv=sys.argv):
 
 COMMANDS.extend([ListCommand, DumpCommand, CopyCommand,
             SetCommand, RemoveCommand, AddCommand, PrintCommand,
-            HelpCommand, ClearCommand, InfoCommand, TagsCommand])
+            HelpCommand, ClearCommand, InfoCommand, TagsCommand,
+            ImageExtractCommand, ImageSetCommand, ImageClearCommand])
 COMMANDS.sort(key=lambda c: c.NAME)
 
 # TODO
-# EditCommand, ImageExtractCommand, FillCommand, RenameCommand
+# EditCommand, FillCommand, RenameCommand
 # FillTracknumberCommand, LoadCommand
 
 if __name__ == "__main__":
