@@ -21,12 +21,14 @@ from quodlibet import qltk
 from quodlibet import util
 from quodlibet.browsers._base import Browser
 from quodlibet.library import SongFileLibrary
-from quodlibet.qltk.filesel import DirectoryTree
+from quodlibet.qltk.filesel import MainDirectoryTree
 from quodlibet.qltk.songsmenu import SongsMenu
 from quodlibet.qltk.x import ScrolledWindow
-from quodlibet.util import copool, split_scan_dirs
+from quodlibet.util import copool
+from quodlibet.util.library import get_scan_dirs
 from quodlibet.util.dprint import print_d
 from quodlibet.util.uri import URI
+from quodlibet.util.path import normalize_path
 
 
 class FileSystem(Browser, Gtk.HBox):
@@ -71,9 +73,7 @@ class FileSystem(Browser, Gtk.HBox):
         sw.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
         sw.set_shadow_type(Gtk.ShadowType.IN)
 
-        folders = filter(None, split_scan_dirs(config.get("settings", "scan")))
-
-        dt = DirectoryTree(folders=folders)
+        dt = MainDirectoryTree(folders=get_scan_dirs())
         targets = [("text/x-quodlibet-songs", Gtk.TargetFlags.SAME_APP,
                     self.TARGET_QL),
                    ("text/uri-list", 0, self.TARGET_EXT)]
@@ -112,9 +112,8 @@ class FileSystem(Browser, Gtk.HBox):
                 return
             to_add = filter(self.__library.__contains__, songs)
             self.__add_songs(view, to_add)
-            filenames = [song("~filename") for song in songs]
-            type_ = Gdk.atom_intern("text/x-quodlibet-songs", True)
-            sel.set(type_, 8, "\x00".join(filenames))
+
+            qltk.selection_set_songs(sel, songs)
         else:
             # External target (app) is delivered a list of URIS of songs
             uris = list(set([URI.frompath(dir) for dir in dirs]))
@@ -141,19 +140,31 @@ class FileSystem(Browser, Gtk.HBox):
             self.__select_paths(paths)
 
     def __select_paths(self, paths):
-        def select(model, path, iter, (paths, first)):
-            if model[iter][0] in paths:
+        # AudioFile uses normalized paths, DirectoryTree doesn't
+
+        paths = map(normalize_path, paths)
+
+        def select(model, path, iter_, (paths, first)):
+            value = model.get_value(iter_)
+            if value is None:
+                return not bool(paths)
+            value = normalize_path(value)
+
+            if value in paths:
                 self.get_child().get_selection().select_path(path)
-                paths.remove(model[iter][0])
+                paths.remove(value)
                 if not first:
                     self.get_child().set_cursor(path)
                     # copy treepath, gets invalid after the callback
                     first.append(path.copy())
             else:
                 for fpath in paths:
-                    if model[path][0] and fpath.startswith(model[path][0]):
+                    if fpath.startswith(value):
                         self.get_child().expand_row(path, False)
             return not bool(paths)
+
+        # XXX: We expect all paths we want in DirectoryTree to be
+        # expanded once before
         first = []
         self.get_child().get_model().foreach(select, (paths, first))
         if first:
@@ -169,8 +180,7 @@ class FileSystem(Browser, Gtk.HBox):
 
     def Menu(self, songs, songlist, library):
         menu = SongsMenu(library, songs, remove=self.__remove_songs,
-                         delete=True, accels=songlist.accelerators,
-                         parent=self)
+                         delete=True, parent=self)
         i = qltk.MenuItem(_("_Add to Library"), Gtk.STOCK_ADD)
         i.set_sensitive(False)
         i.connect('activate', self.__add_songs, songs)
@@ -200,6 +210,7 @@ class FileSystem(Browser, Gtk.HBox):
                 for file in filter(formats.filter,
                                    sorted(os.listdir(util.fsnative(dir)))):
                     fn = os.path.realpath(os.path.join(dir, file))
+                    fn = normalize_path(fn)
                     if fn in self.__glibrary:
                         songs.append(self.__glibrary[fn])
                     elif fn not in self.__library:
