@@ -1,6 +1,6 @@
 # Copyright 2006 Joe Wreschnig
 #           2013 Nick Boultbee
-#           2013 Christoph Reiter
+#           2013,2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -12,18 +12,10 @@ These classes are the most basic library classes. As such they are the
 least useful but most content-agnostic.
 """
 
-# Windows doesn't have fcntl, just don't lock for now
-try:
-    import fcntl
-    fcntl
-except ImportError:
-    fcntl = None
-
 import cPickle as pickle
 import os
 import shutil
 import threading
-from UserDict import DictMixin
 
 from gi.repository import GObject
 
@@ -31,9 +23,12 @@ from quodlibet.formats import MusicFile
 from quodlibet.parse import Query
 from quodlibet.qltk.notif import Task
 from quodlibet.util.collection import Album
+from quodlibet.util.collections import DictMixin
 from quodlibet import util
 from quodlibet import const
+from quodlibet import formats
 from quodlibet.util.dprint import print_d, print_w
+from quodlibet.util.path import fsdecode, expanduser, unexpand, mkdir
 
 
 class Library(GObject.GObject, DictMixin):
@@ -43,6 +38,12 @@ class Library(GObject.GObject, DictMixin):
     attribute, but specific types of libraries may require more
     advanced interfaces.
 
+    Every method which takes a sequence of items expects items to
+    implement __iter__, __len__ and __contains__.
+
+    Likewise the signals emit sequences which implement
+    __iter__, __len__ and __contains__ e.g. set(), list() or tuple().
+
     WARNING: The library implements the dict interface with the exception
     that iterating over it yields values and not keys.
     """
@@ -80,19 +81,22 @@ class Library(GObject.GObject, DictMixin):
         the librarian, this library's changed signal may not fire, but
         another's might.
         """
+
         if not items:
             return
         if self.librarian and self in self.librarian.libraries.itervalues():
             print_d("Changing %d items via librarian." % len(items), self)
             self.librarian.changed(items)
         else:
-            items = filter(self.__contains__, items)
+            items = set(item for item in items if item in self)
             if not items:
                 return
             print_d("Changing %d items directly." % len(items), self)
             self._changed(items)
 
     def _changed(self, items):
+        assert isinstance(items, set)
+
         # Called by the changed method and Librarians.
         if not items:
             return
@@ -158,12 +162,13 @@ class Library(GObject.GObject, DictMixin):
     def add(self, items):
         """Add items. This causes an 'added' signal.
 
-        Return the list of items actually added, filtering out items
+        Return the sequence of items actually added, filtering out items
         already in the library.
         """
-        items = filter(lambda item: item not in self, items)
+
+        items = set(item for item in items if item not in self)
         if not items:
-            return
+            return items
 
         print_d("Adding %d items." % len(items), self)
         for item in items:
@@ -174,9 +179,14 @@ class Library(GObject.GObject, DictMixin):
         return items
 
     def remove(self, items):
-        """Remove items. This causes a 'removed' signal."""
+        """Remove items. This causes a 'removed' signal.
+
+        Return the sequence of items actually removed.
+        """
+
+        items = set(item for item in items if item in self)
         if not items:
-            return
+            return items
 
         print_d("Removing %d items." % len(items), self)
         for item in items:
@@ -184,21 +194,19 @@ class Library(GObject.GObject, DictMixin):
 
         self.dirty = True
         self.emit('removed', items)
+        return items
 
 
 def dump_items(filename, items):
-    """Pickle items to disk"""
+    """Pickle items to disk.
+
+    Doesn't handle exceptions.
+    """
 
     dirname = os.path.dirname(filename)
-    if not os.path.isdir(dirname):
-        os.makedirs(dirname)
-
-    temp_filename = filename + ".tmp"
-
-    with open(temp_filename, "wb") as fileobj:
-        if fcntl is not None:
-            fcntl.flock(fileobj.fileno(), fcntl.LOCK_EX)
+    mkdir(dirname)
 
+    with util.atomic_save(filename, ".tmp", "wb") as fileobj:
         # While protocol 2 is usually faster it uses __setitem__
         # for unpickle and we override it to clear the sort cache.
         # This roundtrip makes it much slower, so we use protocol 1
@@ -207,24 +215,12 @@ def dump_items(filename, items):
         # see: http://bugs.python.org/issue826897
         pickle.dump(items, fileobj, 1)
 
-        fileobj.flush()
-        os.fsync(fileobj.fileno())
-
-        # No atomic rename on windows
-        if os.name == "nt":
-            try:
-                os.remove(filename)
-            except EnvironmentError:
-                pass
-
-        try:
-            os.rename(temp_filename, filename)
-        except EnvironmentError:
-            print_w("Couldn't save library to path: %r" % filename)
-
 
 def load_items(filename, default=None):
-    """Load items from disk"""
+    """Load items from disk.
+
+    In case of an error returns default or an empty list.
+    """
 
     if default is None:
         default = []
@@ -239,8 +235,11 @@ def load_items(filename, default=None):
     # pickle makes 1000 read syscalls for 6000 songs
     # read the file into memory so that there are less
     # context switches. saves 40% CPU time..
-    with fp:
+    try:
         data = fp.read()
+    except IOError:
+        fp.close()
+        return default
 
     try:
         items = pickle.loads(data)
@@ -293,8 +292,12 @@ class PicklingMixin(object):
         with self._save_lock:
             print_d("Saving contents to %r." % filename, self)
 
-            dump_items(filename, self.get_content())
-            self.dirty = False
+            try:
+                dump_items(filename, self.get_content())
+            except EnvironmentError:
+                print_w("Couldn't save library to path: %r" % filename)
+            else:
+                self.dirty = False
 
 
 class PicklingLibrary(Library, PicklingMixin):
@@ -467,7 +470,8 @@ class SongLibrary(PicklingLibrary):
         This requires a special method because it can change the
         song's key.
 
-        The 'changed' signal may fire for this library.
+        The 'changed' signal may fire for this library or the changed
+        song is added to the passed changed set().
 
         If the song exists in multiple libraries you cannot use this
         method. Instead, use the librarian.
@@ -478,9 +482,9 @@ class SongLibrary(PicklingLibrary):
         self._contents[song.key] = song
         if changed is not None:
             print_d("%s: Delaying changed signal." % (type(self).__name__,))
-            changed.append(song)
+            changed.add(song)
         else:
-            self.changed([song])
+            self.changed(set([song]))
 
     def query(self, text, sort=None, star=Query.STAR):
         """Query the library and return matching songs."""
@@ -582,21 +586,25 @@ class FileLibrary(PicklingLibrary):
     def reload(self, item, changed=None, removed=None):
         """Reload a song, possibly noting its status.
 
-        If lists are given, it assumes the caller will handle signals,
-        and only updates the lists. Otherwise, it handles signals
+        If sets are given, it assumes the caller will handle signals,
+        and only updates the sets. Otherwise, it handles signals
         itself. It *always* handles library contents, so do not
-        try to remove (again) a song that appears in the removed list.
+        try to remove (again) a song that appears in the removed set.
         """
+
         was_changed, was_removed = self._load_item(item, force=True)
-        if was_changed and changed is not None:
-            changed.append(item)
-        elif was_removed and removed is not None:
-            removed.append(item)
-        elif changed is None and removed is None:
-            if was_changed:
-                self.changed([item])
-            elif was_removed:
-                self.emit('removed', [item])
+        assert not (was_changed and was_removed)
+
+        if was_changed:
+            if changed is None:
+                self.emit('changed', set([item]))
+            else:
+                changed.add(item)
+        elif was_removed:
+            if removed is None:
+                self.emit('removed', set([item]))
+            else:
+                removed.add(item)
 
     def rebuild(self, paths, force=False, exclude=[], cofuncid=None):
         """Reload or remove songs if they have changed or been deleted.
@@ -628,7 +636,7 @@ class FileLibrary(PicklingLibrary):
         task = Task(_("Library"), _("Scanning library"))
         if cofuncid:
             task.copool(cofuncid)
-        changed, removed = [], []
+        changed, removed = set(), set()
         for i, (key, item) in task.list(enumerate(sorted(self.items()))):
             if key in self._contents and force or not item.valid():
                 self.reload(item, changed, removed)
@@ -637,10 +645,10 @@ class FileLibrary(PicklingLibrary):
             # interactive and doesn't get bogged down in updates.
             if len(changed) > 100:
                 self.emit('changed', changed)
-                changed = []
+                changed = set()
             if len(removed) > 100:
                 self.emit('removed', removed)
-                removed = []
+                removed = set()
             if len(changed) > 5 or i % 100 == 0:
                 yield True
         print_d("Removing %d, changing %d." % (len(removed), len(changed)),
@@ -662,14 +670,14 @@ class FileLibrary(PicklingLibrary):
 
     def scan(self, paths, exclude=[], cofuncid=None):
         added = []
-        exclude = [util.expanduser(path) for path in exclude if path]
+        exclude = [expanduser(path) for path in exclude if path]
         for fullpath in paths:
             print_d("Scanning %r." % fullpath, self)
-            desc = _("Scanning %s") % (util.unexpand(util.fsdecode(fullpath)))
+            desc = _("Scanning %s") % (unexpand(fsdecode(fullpath)))
             with Task(_("Library"), desc) as task:
                 if cofuncid:
                     task.copool(cofuncid)
-                fullpath = util.expanduser(fullpath)
+                fullpath = expanduser(fullpath)
                 if filter(fullpath.startswith, exclude):
                     continue
                 for path, dnames, fnames in os.walk(util.fsnative(fullpath)):
@@ -679,6 +687,9 @@ class FileLibrary(PicklingLibrary):
                             continue
                         if fullfilename not in self._contents:
                             fullfilename = os.path.realpath(fullfilename)
+                            # skip unknown file extensions
+                            if not formats.filter(fullfilename):
+                                continue
                             if filter(fullfilename.startswith, exclude):
                                 continue
                             if fullfilename not in self._contents:
