@@ -8,7 +8,7 @@
 import time
 import operator
 
-from quodlibet.util import fsdecode
+from quodlibet.util.path import fsdecode
 
 
 class error(ValueError):
@@ -165,6 +165,8 @@ class Tag(object):
         names = [Tag.ABBRS.get(n.lower(), n.lower()) for n in names]
         for name in names:
             if name[:1] == "~":
+                if name.startswith("~#"):
+                    raise ValueError("numeric tags not supported")
                 if name in FS_KEYS:
                     self.__fs.append(name)
                 else:
@@ -274,14 +276,16 @@ def map_numeric_op(tag, op, value, time_=None):
 
     # get the biggest float/int
     max_val = ""
-    for i in xrange(1, len(value) + 1):
+    for i in xrange(len(value) + 1, 1, -1):
+        part = value[:i]
         try:
-            float(value[:i])
-            max_val = value[:i]
+            float(part)
         except ValueError:
+            pass
+        else:
+            max_val = part
             break
-
-    if not max_val:
+    else:
         raise ParseError("No numeric value %r" % value)
 
     unit = value[len(max_val):].strip()
