@@ -5,13 +5,13 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 
-import gtk
+from gi.repository import Gtk
+
 from quodlibet import formats, config, print_d
 from quodlibet.util import copool, massagers
 
 
-
-class EntryWordCompletion(gtk.EntryCompletion):
+class EntryWordCompletion(Gtk.EntryCompletion):
     """Entry completion for simple words, where a word boundary is
     roughly equivalent to the separators in the QL query language.
 
@@ -22,14 +22,15 @@ class EntryWordCompletion(gtk.EntryCompletion):
 
     def __init__(self):
         super(EntryWordCompletion, self).__init__()
-        self.set_match_func(self.__match_filter)
+        self.set_match_func(self.__match_filter, None)
         self.connect('match-selected', self.__match_selected)
 
-    def __match_filter(self, completion, entrytext, iter):
+    def __match_filter(self, completion, entrytext, iter, data):
         model = completion.get_model()
         entry = self.get_entry()
         entrytext = entrytext.decode('utf-8')
-        if entry is None: return False
+        if entry is None:
+            return False
         cursor = entry.get_position()
         if (cursor != len(entrytext) and not
             max([entrytext[cursor:].startswith(s) for s in self.rightsep])):
@@ -38,10 +39,13 @@ class EntryWordCompletion(gtk.EntryCompletion):
         # find the border to the left
         left, f = max(
             [(entrytext.rfind(c, 0, cursor), c) for c in self.leftsep])
-        if left < 0: left += 1
-        else: left += len(f)
+        if left < 0:
+            left += 1
+        else:
+            left += len(f)
 
-        if left == cursor: return False
+        if left == cursor:
+            return False
         key = entrytext[left:cursor]
 
         value = model.get_value(iter, self.get_property('text-column'))
@@ -56,14 +60,17 @@ class EntryWordCompletion(gtk.EntryCompletion):
         text = text.decode('utf-8')
         left, f = max(
             [(text.rfind(c, 0, cursor), c) for c in self.leftsep])
-        if left == -1: left += 1
-        else: left += len(f)
+        if left == -1:
+            left += 1
+        else:
+            left += len(f)
         offset = cursor - left
 
         entry.insert_text(value[offset:], cursor)
         entry.set_position(left + len(value))
         return True
 
+
 class LibraryTagCompletion(EntryWordCompletion):
     """A completion for text entries tied to a library's tag list."""
 
@@ -71,9 +78,10 @@ class LibraryTagCompletion(EntryWordCompletion):
 
     def __init__(self, library):
         super(LibraryTagCompletion, self).__init__()
-        try: model = self.__model
+        try:
+            model = self.__model
         except AttributeError:
-            model = type(self).__model = gtk.ListStore(str)
+            model = type(self).__model = Gtk.ListStore(str)
             library.connect('changed', self.__update_song, model)
             library.connect('added', self.__update_song, model)
             library.connect('removed', self.__update_song, model)
@@ -119,7 +127,8 @@ class LibraryTagCompletion(EntryWordCompletion):
                     "mtime", "added", "rating", "length"]:
             tags.add("#(" + tag)
         for tag in ["date", "bpm"]:
-            if tag in all_tags: tags.add("#(" + tag)
+            if tag in all_tags:
+                tags.add("#(" + tag)
 
         tags -= all_tags
         for tag in tags:
@@ -128,13 +137,14 @@ class LibraryTagCompletion(EntryWordCompletion):
 
         print_d("Done updating tag model for whole library")
 
-class LibraryValueCompletion(gtk.EntryCompletion):
+
+class LibraryValueCompletion(Gtk.EntryCompletion):
     """Entry completion for a library value, for a specific tag.
     Will add valid values from the tag massager where available"""
 
     def __init__(self, tag, library):
         super(LibraryValueCompletion, self).__init__()
-        self.set_model(gtk.ListStore(str))
+        self.set_model(Gtk.ListStore(str))
         self.set_text_column(0)
         self.set_tag(tag, library)
 
@@ -157,7 +167,8 @@ class LibraryValueCompletion(gtk.EntryCompletion):
         # Issue 439: pre-fill with valid values if available
         if tag in massagers.tags:
             values = massagers.tags[tag].options
-        else: values = []
+        else:
+            values = []
         values = sorted(set(values + library.tag_values(tag)))
         self.set_minimum_key_length(int(len(values) > 100))
         yield True
