@@ -24,6 +24,10 @@ from quodlibet.qltk.wlw import WritingWindow
 from quodlibet.qltk.x import SeparatorMenuItem
 from quodlibet.qltk._editpane import EditingPluginHandler
 from quodlibet.plugins import PluginManager
+from quodlibet.util.path import fsdecode
+from quodlibet.util.string import decode
+from quodlibet.util.string.splitters import (split_value, split_title,
+    split_people, split_album)
 
 
 class AudioFileGroup(dict):
@@ -107,7 +111,7 @@ class AudioFileGroup(dict):
             else:
                 decoded = first[comment]
                 if isinstance(decoded, str):
-                    decoded = util.decode(decoded)
+                    decoded = decode(decoded)
                 if all[comment]:
                     value = self.SharedComment(decoded)
                 else:
@@ -148,12 +152,12 @@ class SplitValues(Gtk.ImageMenuItem):
             Gtk.STOCK_FIND_AND_REPLACE, Gtk.IconSize.MENU))
         spls = config.get("editing", "split_on").decode(
             'utf-8', 'replace').split()
-        self.set_sensitive(len(util.split_value(value, spls)) > 1)
+        self.set_sensitive(len(split_value(value, spls)) > 1)
 
     def activated(self, tag, value):
         spls = config.get("editing", "split_on").decode(
             'utf-8', 'replace').split()
-        return [(tag, v) for v in util.split_value(value, spls)]
+        return [(tag, v) for v in split_value(value, spls)]
 
 
 class SplitDisc(Gtk.ImageMenuItem):
@@ -166,10 +170,10 @@ class SplitDisc(Gtk.ImageMenuItem):
             _("Split Disc out of _Album"), use_underline=True)
         self.set_image(Gtk.Image.new_from_stock(
             Gtk.STOCK_FIND_AND_REPLACE, Gtk.IconSize.MENU))
-        self.set_sensitive(util.split_album(value)[1] is not None)
+        self.set_sensitive(split_album(value)[1] is not None)
 
     def activated(self, tag, value):
-        album, disc = util.split_album(value)
+        album, disc = split_album(value)
         return [(tag, album), ("discnumber", disc)]
 
 
@@ -185,12 +189,12 @@ class SplitTitle(Gtk.ImageMenuItem):
             Gtk.STOCK_FIND_AND_REPLACE, Gtk.IconSize.MENU))
         spls = config.get("editing", "split_on").decode(
             'utf-8', 'replace').split()
-        self.set_sensitive(bool(util.split_title(value, spls)[1]))
+        self.set_sensitive(bool(split_title(value, spls)[1]))
 
     def activated(self, tag, value):
         spls = config.get("editing", "split_on").decode(
             'utf-8', 'replace').split()
-        title, versions = util.split_title(value, spls)
+        title, versions = split_title(value, spls)
         return [(tag, title)] + [("version", v) for v in versions]
 
 
@@ -204,12 +208,12 @@ class SplitPerson(Gtk.ImageMenuItem):
             Gtk.STOCK_FIND_AND_REPLACE, Gtk.IconSize.MENU))
         spls = config.get("editing", "split_on").decode(
             'utf-8', 'replace').split()
-        self.set_sensitive(bool(util.split_people(value, spls)[1]))
+        self.set_sensitive(bool(split_people(value, spls)[1]))
 
     def activated(self, tag, value):
         spls = config.get("editing", "split_on").decode(
             'utf-8', 'replace').split()
-        artist, others = util.split_people(value, spls)
+        artist, others = split_people(value, spls)
         return [(tag, artist)] + [(self.needs[0], o) for o in others]
 
 
@@ -489,7 +493,9 @@ class EditTags(Gtk.VBox):
         view.connect('key-press-event', self.__view_key_press_event)
         selection.connect('changed', self.__tag_select, remove)
         selection.set_mode(Gtk.SelectionMode.MULTIPLE)
-        self.show_all()
+
+        for child in self.get_children():
+            child.show_all()
 
     def __view_key_press_event(self, view, event):
         # We can't use a real accelerator to this because it would
@@ -654,25 +660,26 @@ class EditTags(Gtk.VBox):
             if row[EDITED] and not (row[DELETED] or row[RENAMED]):
                 if row[ORIGVALUE] is not None:
                     updated.setdefault(row[TAG], [])
-                    updated[row[TAG]].append((util.decode(row[VALUE]),
-                                              util.decode(row[ORIGVALUE])))
+                    updated[row[TAG]].append((decode(row[VALUE]),
+                                              decode(row[ORIGVALUE])))
                 else:
                     added.setdefault(row[TAG], [])
-                    added[row[TAG]].append(util.decode(row[VALUE]))
+                    added[row[TAG]].append(decode(row[VALUE]))
             if row[EDITED] and row[DELETED]:
                 if row[ORIGVALUE] is not None:
                     deleted.setdefault(row[TAG], [])
-                    deleted[row[TAG]].append(util.decode(row[ORIGVALUE]))
+                    deleted[row[TAG]].append(decode(row[ORIGVALUE]))
 
             if row[EDITED] and row[RENAMED] and not row[DELETED]:
                 renamed.setdefault(row[TAG], [])
-                renamed[row[TAG]].append((util.decode(row[ORIGTAG]),
-                                          util.decode(row[VALUE]),
-                                          util.decode(row[ORIGVALUE])))
+                renamed[row[TAG]].append((decode(row[ORIGTAG]),
+                                          decode(row[VALUE]),
+                                          decode(row[ORIGVALUE])))
 
-        was_changed = []
+        was_changed = set()
         songs = self.__songinfo.songs
         win = WritingWindow(self, len(songs))
+        win.show()
         for song in songs:
             if not song.valid() and not qltk.ConfirmAction(
                 self, _("Tag may not be accurate"),
@@ -738,11 +745,11 @@ class EditTags(Gtk.VBox):
                         _("Saving <b>%s</b> failed. The file "
                           "may be read-only, corrupted, or you "
                           "do not have permission to edit it.") % (
-                        util.escape(util.fsdecode(
+                        util.escape(fsdecode(
                         song('~basename'))))).run()
                     library.reload(song, changed=was_changed)
                     break
-                was_changed.append(song)
+                was_changed.add(song)
 
             if win.step():
                 break
@@ -820,7 +827,7 @@ class EditTags(Gtk.VBox):
                 row[TAG] = new_tag
 
     def __button_press(self, view, event):
-        if event.button not in [1, 2]:
+        if event.button not in [Gdk.BUTTON_PRIMARY, Gdk.BUTTON_MIDDLE]:
             return False
         x, y = map(int, [event.x, event.y])
         try:
@@ -828,7 +835,7 @@ class EditTags(Gtk.VBox):
         except TypeError:
             return False
 
-        if event.button == 1 and col is view.get_columns()[0]:
+        if event.button == Gdk.BUTTON_PRIMARY and col is view.get_columns()[0]:
             row = view.get_model()[path]
             row[EDITED] = not row[EDITED]
             if row[EDITED]:
@@ -836,11 +843,15 @@ class EditTags(Gtk.VBox):
                 if idx >= 0:
                     row[VALUE] = row[VALUE][:idx].strip()
             return True
-        elif event.button == 2 and col == view.get_columns()[2]:
-            display = Gdk.display_manager_get().get_default_display()
-            clipboardname = ["PRIMARY", "CLIPBOARD"][sys.platform == "win32"]
-            clipboard = Gtk.Clipboard(display, clipboardname)
-            for rend in col.get_cell_renderers():
+        elif event.button == Gdk.BUTTON_MIDDLE and \
+                col == view.get_columns()[2]:
+            display = Gdk.DisplayManager.get().get_default_display()
+            selection = Gdk.SELECTION_PRIMARY
+            if sys.platform == "win32":
+                selection = Gdk.SELECTION_CLIPBOARD
+
+            clipboard = Gtk.Clipboard.get_for_display(display, selection)
+            for rend in col.get_cells():
                 if rend.get_property('editable'):
                     clipboard.request_text(self.__paste,
                                            (rend, path.get_indices()[0]))
@@ -855,9 +866,9 @@ class EditTags(Gtk.VBox):
             songs = self.__songinfo.songs
 
         self.__songinfo = songinfo = AudioFileGroup(songs)
-        view.set_model(None)
-        model.clear()
-        view.set_model(model)
+
+        with view.without_model() as model:
+            model.clear()
 
         keys = sorted(songinfo.realkeys())
 
