@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman, Iñigo Serna
+#           2013 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -12,8 +13,8 @@ from gi.repository import Gdk, GObject, GLib
 import quodlibet
 from quodlibet import const
 from quodlibet import config
-from quodlibet import util
 from quodlibet.qltk.msg import ErrorMessage
+from quodlibet.util.string import decode
 
 MAX_ERRORS = 10
 
@@ -41,7 +42,8 @@ class TimeTracker(GObject.GObject):
         ]
 
     def destroy(self):
-        map(self.__player.disconnect, self.__sigs)
+        for signal_id in self.__sigs:
+            self.__player.disconnect(signal_id)
         self.__source_remove()
 
     def __source_remove(self):
@@ -77,11 +79,13 @@ class SongTracker(object):
         timer.connect("tick", self.__timer)
         self.__errors_in_a_row = 0
         self.elapsed = 0
+        self.__to_change = set()
+        self.__change_id = None
         quodlibet.quit_add(1, self.__quit, librarian, player)
 
     def __error(self, player, song, error, librarian):
         newstr = u"%s: %s\n\n" % (
-            util.decode(time.asctime(), const.ENCODING), error)
+            decode(time.asctime(), const.ENCODING), error)
         self.__errors_in_a_row += 1
         if self.__errors_in_a_row > MAX_ERRORS:
             self.__errors_in_a_row = 0
@@ -92,6 +96,22 @@ class SongTracker(object):
             player.paused = True
         song["~errors"] = newstr + song.get("~errors", "")
 
+    def __changed(self, librarian, song):
+        # try to combine changed events and process them if QL is idle
+        self.__to_change.add(song)
+
+        if self.__change_id is not None:
+            GLib.source_remove(self.__change_id)
+            self.__change_id = None
+
+        def idle_change():
+            librarian.changed(list(self.__to_change))
+            self.__to_change.clear()
+            self.__change_id = None
+
+        self.__change_id = GLib.idle_add(idle_change,
+                                         priority=GLib.PRIORITY_LOW)
+
     def __start(self, librarian, song):
         self.elapsed = 0
         if song is not None:
@@ -101,7 +121,7 @@ class SongTracker(object):
             else:
                 config.set("memory", "song", song["~filename"])
             song["~#laststarted"] = int(time.time())
-            librarian.changed([song])
+            self.__changed(librarian, song)
         else:
             config.set("memory", "song", "")
 
@@ -111,11 +131,11 @@ class SongTracker(object):
         elif self.elapsed > 0.5 * song.get("~#length", 1):
             song["~#lastplayed"] = int(time.time())
             song["~#playcount"] = song.get("~#playcount", 0) + 1
-            librarian.changed([song])
+            self.__changed(librarian, song)
         elif pl.current is not song:
             if "~errors" not in song:
                 song["~#skipcount"] = song.get("~#skipcount", 0) + 1
-            librarian.changed([song])
+            self.__changed(librarian, song)
 
         if not ended and song and "~errors" in song:
             del(song["~errors"])
