@@ -1,6 +1,6 @@
-from tests import TestCase
+from tests import AbstractTestCase, skipUnless
 from quodlibet.util.modulescanner import ModuleScanner
-from quodlibet.plugins import list_plugins
+from quodlibet.plugins import list_plugins, Plugin
 import sys
 import os
 
@@ -13,11 +13,12 @@ ms.rescan()
 plugins = {}
 modules = {}
 for name, module in ms.modules.iteritems():
-    for plugin in list_plugins(module):
-        plugins[plugin.PLUGIN_ID] = plugin
-        modules[plugin.PLUGIN_ID] = module
+    for plugin in list_plugins(module.module):
+        plugins[plugin.PLUGIN_ID] = Plugin(plugin)
+        modules[plugin.PLUGIN_ID] = module.module
 
-class PluginTestCase(TestCase):
+
+class PluginTestCase(AbstractTestCase):
     """Base class for all plugin tests"""
     plugins = plugins
     modules = modules
