@@ -1,10 +1,11 @@
-from tests import TestCase, add
+from tests import TestCase
 
 from quodlibet.browsers.audiofeeds import AudioFeeds
 from quodlibet.player.nullbe import NullPlayer
 from quodlibet.library import SongLibrary
 import quodlibet.config
 
+
 class TAudioFeeds(TestCase):
     def setUp(self):
         quodlibet.config.init()
@@ -19,4 +20,3 @@ class TAudioFeeds(TestCase):
         self.bar.destroy()
         self.library.destroy()
         quodlibet.config.quit()
-add(TAudioFeeds)
