@@ -1,11 +1,23 @@
-from tests import TestCase, add
+from tests import TestCase
+
+from gi.repository import Gtk
 
 from quodlibet.library import SongLibrary
 from quodlibet.formats._audio import AudioFile
-from quodlibet.browsers.iradio import InternetRadio, IRFile
+from quodlibet.browsers.iradio import InternetRadio, IRFile, QuestionBar
 from quodlibet.player.nullbe import NullPlayer
 import quodlibet.config
 
+quodlibet.config.RATINGS = quodlibet.config.HardCodedRatingsPrefs()
+
+
+class TQuestionBar(TestCase):
+
+    def test_main(self):
+        b = QuestionBar()
+        self.assertFalse(b.get_visible())
+
+
 class TInternetRadio(TestCase):
     def setUp(self):
         quodlibet.config.init()
@@ -18,7 +30,6 @@ class TInternetRadio(TestCase):
     def tearDown(self):
         self.bar.destroy()
         quodlibet.config.quit()
-add(TInternetRadio)
 
 
 class TIRFile(TestCase):
@@ -81,5 +92,3 @@ class TIRFile(TestCase):
         new.from_dump(dump)
         self.assertTrue("title" not in new)
         self.assertTrue("artist" not in new)
-
-add(TIRFile)
