@@ -1,10 +1,11 @@
-from tests import TestCase, add
+from quodlibet.browsers.playlists.util import parse_m3u, parse_pls
+from quodlibet.util.collection import Playlist
+from tests import TestCase, AbstractTestCase, DATA_DIR, mkstemp, mkdtemp
 
 import os
-import tempfile
 import shutil
 
-from quodlibet.browsers.playlists import ParseM3U, ParsePLS, Playlist, Playlists
+from quodlibet.browsers.playlists import PlaylistsBrowser
 from quodlibet.player.nullbe import NullPlayer
 from quodlibet.library import SongLibrary
 import quodlibet.config
@@ -13,10 +14,7 @@ from quodlibet.library.librarians import SongLibrarian
 from quodlibet.library.libraries import FileLibrary
 
 
-def makename():
-    return tempfile.mkstemp()[1]
-
-class TParsePlaylist(TestCase):
+class TParsePlaylist(AbstractTestCase):
     def setUp(self):
         quodlibet.config.init()
 
@@ -24,7 +22,8 @@ class TParsePlaylist(TestCase):
         quodlibet.config.quit()
 
     def test_parse_empty(self):
-        name = makename()
+        h, name = mkstemp()
+        os.close(h)
         file(name, "w").close()
         pl = self.Parse(name)
         os.unlink(name)
@@ -32,10 +31,11 @@ class TParsePlaylist(TestCase):
         pl.delete()
 
     def test_parse_onesong(self):
-        name = makename()
+        h, name = mkstemp()
+        os.close(h)
         f = file(name, "w")
         target = self.prefix
-        target += os.path.join(os.getcwd(), "tests/data/silence-44-s.ogg")
+        target += os.path.join(DATA_DIR, "silence-44-s.ogg")
         f.write(target)
         f.close()
         list = self.Parse(name)
@@ -45,8 +45,9 @@ class TParsePlaylist(TestCase):
         list.delete()
 
     def test_parse_onesong_uri(self):
-        name = makename()
-        target = os.path.join(os.getcwd(), "tests/data/silence-44-s.ogg")
+        h, name = mkstemp()
+        os.close(h)
+        target = os.path.join(DATA_DIR, "silence-44-s.ogg")
         from quodlibet.util.uri import URI
         target = URI.frompath(target)
         target = self.prefix + target
@@ -59,57 +60,15 @@ class TParsePlaylist(TestCase):
         self.failUnlessEqual(list[0]("title"), "Silence")
         list.delete()
 
+
 class TParseM3U(TParsePlaylist):
-    Parse = staticmethod(ParseM3U)
+    Parse = staticmethod(parse_m3u)
     prefix = ""
-add(TParseM3U)
+
 
 class TParsePLS(TParsePlaylist):
-    Parse = staticmethod(ParsePLS)
+    Parse = staticmethod(parse_pls)
     prefix = "File1="
-add(TParsePLS)
-
-class TPlaylist(TestCase):
-    def setUp(self):
-        self._dir = tempfile.mkdtemp()
-
-    def tearDown(self):
-        shutil.rmtree(self._dir)
-
-    def test_make(self):
-        p1 = Playlist.new(self._dir, "Does not exist")
-        self.failUnlessEqual(0, len(p1))
-        self.failUnlessEqual(p1.name, "Does not exist")
-        p1.delete()
-
-    def test_rename_working(self):
-        p1 = Playlist.new(self._dir, "Foobar")
-        p1.rename("Foo Quuxly")
-        self.failUnlessEqual(p1.name, "Foo Quuxly")
-        p1.delete()
-
-    def test_rename_nothing(self):
-        p1 = Playlist.new(self._dir, "Foobar")
-        self.failUnlessRaises(ValueError, p1.rename, "")
-        p1.delete()
-
-    def test_rename_dup(self):
-        p1 = Playlist.new(self._dir, "Foobar")
-        p2 = Playlist.new(self._dir, "Crazy")
-        self.failUnlessRaises(ValueError, p2.rename, "Foobar")
-        p1.delete()
-        p2.delete()
-
-    def test_make_dup(self):
-        p1 = Playlist.new(self._dir, "Does not exist")
-        p2 = Playlist.new(self._dir, "Does not exist")
-        self.failUnlessEqual(p1.name, "Does not exist")
-        self.failUnless(p2.name.startswith("Does not exist"))
-        self.failIfEqual(p1.name, p2.name)
-        p1.delete()
-        p2.delete()
-
-add(TPlaylist)
 
 
 class TPlaylistIntegration(TestCase):
@@ -144,7 +103,7 @@ class TPlaylistIntegration(TestCase):
         for af in self.SONGS:
             af.sanitize()
         self.lib.add(self.SONGS)
-        self._dir = tempfile.mkdtemp()
+        self._dir = mkdtemp()
         self.pl = Playlist.new(self._dir, "Foobar")
         self.pl.extend(self.SONGS)
 
@@ -174,21 +133,18 @@ class TPlaylistIntegration(TestCase):
         self.pl.extend([self.SONG, self.SONG])
         self.failUnlessEqual(len(self.pl), 7)
         self.pl.remove_songs([self.SONG], self.lib, False)
-        self.failUnlessEqual(len(self.pl), 7-2-2)
+        self.failUnlessEqual(len(self.pl), 7 - 2 - 2)
 
     def test_remove_duplicated_song_leave_dupes(self):
         self.pl.remove_songs([self.SONGS[1]], self.lib, True)
         self.failUnlessEqual(len(self.pl), len(self.SONGS) - 1)
 
 
-add(TPlaylistIntegration)
-
-
 class TPlaylists(TestCase):
     def setUp(self):
         quodlibet.config.init()
         self.library = SongLibrary()
-        self.bar = Playlists(SongLibrary(), NullPlayer())
+        self.bar = PlaylistsBrowser(SongLibrary(), NullPlayer())
 
     def test_can_filter(self):
         for key in ["foo", "title", "fake~key", "~woobar", "~#huh"]:
@@ -198,4 +154,3 @@ class TPlaylists(TestCase):
         self.bar.destroy()
         self.library.destroy()
         quodlibet.config.quit()
-add(TPlaylists)
