@@ -1,9 +1,8 @@
-from tests import TestCase, add
+from tests import TestCase, DATA_DIR, mkstemp
 
 import os
 
 from quodlibet import config
-from quodlibet.util import HashableDict
 from quodlibet.formats._audio import AudioFile
 from quodlibet.formats._audio import INTERN_NUM_DEFAULT
 
@@ -18,7 +17,7 @@ bar_1_2 = AudioFile({
     "discnumber": "1", "tracknumber": "2/3",
     "artist": "Lali-ho!", "album": "Bar",
     "date": "2004-12-12", "originaldate": "2005-01-01",
-    "~#filesize": 1024**2})
+    "~#filesize": 1024 ** 2})
 bar_2_1 = AudioFile({
     "~filename": "does not/exist",
     "title": "more songs",
@@ -27,14 +26,16 @@ bar_2_1 = AudioFile({
     "lyricist": "Foo", "composer": "Foo", "performer": "I have two artists"})
 
 quux = AudioFile({
-    "~filename": "tests/data/asong.ogg",
-    "album": "Quuxly"
+    "~filename": os.path.join(DATA_DIR, "asong.ogg"),
+    "album": u"Quuxly"
     })
 
 num_call = AudioFile({"custom": "0.3"})
 
+
 class TAudioFile(TestCase):
     def setUp(self):
+        config.RATINGS = config.HardCodedRatingsPrefs()
         file(quux["~filename"], "w")
 
     def test_sort(self):
@@ -68,7 +69,7 @@ class TAudioFile(TestCase):
         self.failUnlessEqual(quux("not a key", "foo"), "foo")
         self.failUnlessEqual(quux("artist"), "")
         self.failUnlessEqual(quux("~basename"), "asong.ogg")
-        self.failUnlessEqual(quux("~dirname"), "tests/data")
+        self.failUnlessEqual(quux("~dirname"), DATA_DIR)
         self.failUnlessEqual(quux("title"), "asong.ogg [Unknown]")
 
         self.failUnlessEqual(bar_1_1("~#disc"), 1)
@@ -85,7 +86,7 @@ class TAudioFile(TestCase):
 
     def test_filesize(self):
         self.failUnlessEqual(bar_1_2("~filesize"), "1.00 MB")
-        self.failUnlessEqual(bar_1_2("~#filesize"), 1024**2)
+        self.failUnlessEqual(bar_1_2("~#filesize"), 1024 ** 2)
 
     def test_originalyear(self):
         self.failUnlessEqual(bar_1_2("~originalyear"), "2005")
@@ -102,8 +103,10 @@ class TAudioFile(TestCase):
         for song in [quux, bar_1_1, bar_2_1]:
             self.failUnlessEqual(song("~~people"), song("~people"))
             self.failUnlessEqual(song("~title~people"), song("title"))
-            self.failUnlessEqual(song("~title~~people"), song("~title~artist"))
-            self.failUnlessEqual(song("~title~~#tracks"), song("~title~~#tracks"))
+            self.failUnlessEqual(
+                song("~title~~people"), song("~title~artist"))
+            self.failUnlessEqual(
+                song("~title~~#tracks"), song("~title~~#tracks"))
 
     def test_call_numeric(self):
         self.failUnlessAlmostEqual(num_call("~#custom"), 0.3)
@@ -171,10 +174,11 @@ class TAudioFile(TestCase):
     def test_rename(self):
         old_fn = quux("~basename")
         new_fn = "anothersong.mp3"
-        dir = os.getcwd() + "/tests/data/"
+        dir = DATA_DIR
         self.failUnless(quux.exists())
         quux.rename(new_fn)
-        self.failIf(os.path.exists(dir + old_fn))
+        self.failIf(os.path.exists(dir + old_fn),
+                    "%s already exists" % (dir + old_fn))
         self.failUnless(quux.exists())
         quux.rename(old_fn)
         self.failIf(os.path.exists(dir + new_fn))
@@ -189,8 +193,10 @@ class TAudioFile(TestCase):
 
     def test_rename_to_existing(self):
         quux.rename(quux("~basename"))
-        self.failUnlessRaises(ValueError, quux.rename, "/dev/null")
-        self.failUnlessRaises(ValueError, quux.rename, "silence-44-s.ogg")
+        if os.name != "nt":
+            self.failUnlessRaises(ValueError, quux.rename, "/dev/null")
+        self.failUnlessRaises(ValueError, quux.rename,
+                              os.path.join(DATA_DIR, "silence-44-s.ogg"))
 
     def test_website(self):
         song = AudioFile()
@@ -203,7 +209,8 @@ class TAudioFile(TestCase):
         self.failUnlessEqual(song.website(), "foo")
 
         song = AudioFile({"artist": "Artist", "album": "Album"})
-        for value in song.values(): self.failUnless(value in song.website())
+        for value in song.values():
+            self.failUnless(value in song.website())
         song["labelid"] = "QL-12345"
         self.failIf(song["artist"] in song.website())
         self.failUnless(song["labelid"] in song.website())
@@ -245,7 +252,8 @@ class TAudioFile(TestCase):
         self.failUnless(set(dump.split("\n")) == set(n.to_dump().split("\n")))
 
     def test_to_dump_long(self):
-        b = AudioFile(bar_1_1); b["~#length"] = 200000000000L
+        b = AudioFile(bar_1_1)
+        b["~#length"] = 200000000000L
         dump = b.to_dump()
         num = len(set(bar_1_1.keys()) | INTERN_NUM_DEFAULT)
         self.failUnlessEqual(dump.count("\n"), num + 2)
@@ -323,67 +331,31 @@ class TAudioFile(TestCase):
     def test_set_bookmarks_invalid_value(self):
         self.failUnlessRaises(
             ValueError, setattr, AudioFile(), 'bookmarks', "huh?")
+
     def test_set_bookmarks_invalid_time(self):
         self.failUnlessRaises(
             TypeError, setattr, AudioFile(), 'bookmarks', [("notint", "!")])
+
     def test_set_bookmarks_unrealistic_time(self):
         self.failUnlessRaises(
             ValueError, setattr, AudioFile(), 'bookmarks', [(-1, "!")])
 
     def test_album_key(self):
         album_key_tests = [
-            ({}, ('', '')),
-            ({'album': 'foo'}, (('foo',), '')),
-            ({'labelid': 'foo'}, ('', 'foo')),
-            ({'musicbrainz_albumid': 'foo'}, ('', 'foo')),
-            ({'album': 'foo', 'labelid': 'bar'}, (('foo',), 'bar')),
+            ({}, ('', '', '')),
+            ({'album': 'foo'}, (('foo',), '', '')),
+            ({'labelid': 'foo'}, ('', '', 'foo')),
+            ({'musicbrainz_albumid': 'foo'}, ('', '', 'foo')),
+            ({'album': 'foo', 'labelid': 'bar'}, (('foo',), '', 'bar')),
             ({'album': 'foo', 'labelid': 'bar', 'musicbrainz_albumid': 'quux'},
-                (('foo',), 'bar'))
+                (('foo',), '', 'bar')),
+            ({'albumartist': 'a'}, ('', ('a',), '')),
             ]
         for tags, expected in album_key_tests:
             afile = AudioFile(**tags)
             afile.sanitize('/dir/fn')
             self.failUnlessEqual(afile.album_key, expected)
 
-    def test_album_id_values(self):
-        album_key_tests = [
-            ({}, {}),
-            ({'album': 'foo'}, None),
-            ({'labelid': 'foo'}, None),
-            ({'musicbrainz_albumid': 'foo'}, None),
-            ({'album': 'foo', 'labelid': 'bar'}, {'labelid': 'bar'}),
-            # Musicbrainz is our current "favourite" tag
-            ({'album': 'foo', 'labelid': 'bar', 'musicbrainz_albumid': 'quux'},
-                    {'musicbrainz_albumid': 'quux'}),
-            # albumartist > album in this case
-            ({'album': 'foo', 'albumartist': 'bar', 'artist': 'baz'},
-                    {'album': 'foo', 'albumartist': 'bar'}),
-            # Fail as there's nothing to specify the album
-            ({'albumartist': 'bar', 'artist': 'baz', 'title': 'foo'}, {})
-            ]
-        for tags, expected in album_key_tests:
-            if expected is None: expected = tags
-            afile = AudioFile(**tags)
-            afile.sanitize('/dir/fn')
-            self.failUnlessEqual(afile.album_id_values, HashableDict(expected))
-
-    def test_album_id_values_with_artist(self):
-        album_key_tests = [
-            # The artist should now appear
-            ({'album': 'foo', 'artist': 'bar', 'title': 'baz'},
-                    {'album': 'foo', 'artist': 'bar'}),
-            # But albumartist > album still
-            ({'album': 'foo', 'albumartist': 'bar', 'artist': 'baz'},
-                    {'album': 'foo', 'albumartist': 'bar'}),
-            ]
-        for tags, expected in album_key_tests:
-            if expected is None: expected = tags
-            afile = AudioFile(**tags)
-            afile.sanitize('/dir/fn')
-            # Use alternate version, that includes artist in dict
-            self.failUnlessEqual(afile._album_id_values(True),
-                                 HashableDict(expected))
-
     def test_eq_ne(self):
         self.failIf(AudioFile({"a": "b"}) == AudioFile({"a": "b"}))
         self.failUnless(AudioFile({"a": "b"}) != AudioFile({"a": "b"}))
@@ -443,12 +415,13 @@ class TAudioFile(TestCase):
         f = AudioFile({"~filename": "/\x87\x12.mp3", "title": "linux"})
         self.failUnlessEqual(f("~uri"), "file:///%87%12.mp3")
 
-        f = AudioFile({"~filename": u"/\xf6\xe4.mp3", "title": "win"})
-        self.failUnlessEqual(f("~uri"), "file:///%C3%B6%C3%A4.mp3")
+        if os.name == "nt":
+            f = AudioFile({"~filename": u"/\xf6\xe4.mp3", "title": "win"})
+            self.failUnlessEqual(f("~uri"), "file:///%C3%B6%C3%A4.mp3")
 
     def tearDown(self):
         os.unlink(quux["~filename"])
-add(TAudioFile)
+
 
 class Treplay_gain(TestCase):
 
@@ -520,11 +493,12 @@ class Treplay_gain(TestCase):
             album_rg = self.song("~#%s" % key)
             try:
                 val = float(album_rg)
-            except ValueError: self.fail("Invalid %s returned: %s" %
-                                         (key,album_rg))
-            self.failUnlessAlmostEqual(val, exp, places=5,
-                                 msg="%s should be %s not %s" % (key,exp,val))
-add(Treplay_gain)
+            except ValueError:
+                self.fail("Invalid %s returned: %s" % (key, album_rg))
+            self.failUnlessAlmostEqual(
+                val, exp, places=5,
+                msg="%s should be %s not %s" % (key, exp, val))
+
 
 # Special test case for find_cover since it has to create/remove
 # various files.
@@ -535,7 +509,8 @@ class Tfind_cover(TestCase):
         self.files = [self.full_path("12345.jpg"),
                       self.full_path("nothing.jpg")
                       ]
-        for f in self.files: file(f, "w").close()
+        for f in self.files:
+            file(f, "w").close()
 
     def full_path(self, path):
         return os.path.join(self.dir, path)
@@ -562,6 +537,17 @@ class Tfind_cover(TestCase):
             self.failUnlessEqual(os.path.abspath(quux.find_cover().name), f)
         self.test_labelid() # labelid must work with other files present
 
+    def test_file_encoding(self):
+        if os.name == "nt":
+            return
+
+        f = self.full_path("\xff\xff\xff\xff - cover.jpg")
+        file(f, "w").close()
+        self.files.append(f)
+        self.assertTrue(isinstance(quux("album"), unicode))
+        h = quux.find_cover()
+        self.assertEqual(h.name, f)
+
     def test_intelligent(self):
         song = quux
         song["artist"] = "Q-Man"
@@ -581,7 +567,7 @@ class Tfind_cover(TestCase):
                 self.failUnlessEqual(f, self.full_path("Quuxly - back.jpg"))
 
     def test_embedded_special_cover_words(self):
-        """Tests that words incidentally containing embedded "special" words 
+        """Tests that words incidentally containing embedded "special" words
         album keywords (e.g. cover, disc, back) don't trigger
         See Issue 818"""
 
@@ -603,12 +589,12 @@ class Tfind_cover(TestCase):
             cover = song.find_cover()
             if cover:
                 actual = os.path.abspath(cover.name)
-                self.failUnlessEqual(actual, f,
-                                     "\"%s\" should trump \"%s\"" % (f, actual))
+                self.failUnlessEqual(
+                    actual, f, "\"%s\" should trump \"%s\"" % (f, actual))
             else:
-                self.failUnless(f, self.full_path('back.jpg'));
+                self.failUnless(f, self.full_path('back.jpg'))
 
     def tearDown(self):
-        map(os.unlink, self.files)
+        for f in self.files:
+            os.unlink(f)
         config.quit()
-add(Tfind_cover)
