@@ -1,15 +1,25 @@
 # -*- coding: utf-8 -*-
 
+import os
 import contextlib
 
-from gi.repository import Gst
+try:
+    from gi.repository import Gst
+except ImportError:
+    Gst = None
 
 import unittest
-from tests import TestCase, add
+from tests import TestCase, skipUnless
+
+try:
+    from quodlibet.player.gstbe.util import GStreamerSink as Sink
+    from quodlibet.player.gstbe.util import parse_gstreamer_taglist
+    from quodlibet.player.gstbe.prefs import GstPlayerPreferences
+except ImportError:
+    pass
 
-from quodlibet.player.gstbe import GStreamerSink as Sink
-from quodlibet.player.gstbe import parse_gstreamer_taglist
 from quodlibet.util import sanitize_tags
+from quodlibet import config
 
 
 @contextlib.contextmanager
@@ -20,6 +30,21 @@ def ignore_gst_errors():
     Gst.debug_set_default_threshold(old)
 
 
+@skipUnless(Gst, "GStreamer missing")
+class TGstPlayerPrefs(TestCase):
+
+    def setUp(self):
+        config.init()
+
+    def tearDown(self):
+        config.quit()
+
+    def test_main(self):
+        widget = GstPlayerPreferences(None, True)
+        widget.destroy()
+
+
+@skipUnless(Gst, "GStreamer missing")
 class TGStreamerSink(TestCase):
     def test_simple(self):
         sinks = ["gconfaudiosink", "alsasink"]
@@ -36,15 +61,18 @@ class TGStreamerSink(TestCase):
             obj, name = Sink("notarealsink")
         __builtin__.__dict__["print_w"] = pw
         self.failUnless(obj)
-        self.failUnlessEqual(name, "autoaudiosink")
+        if os.name == "nt":
+            self.failUnlessEqual(name, "directsoundsink")
+        else:
+            self.failUnlessEqual(name, "autoaudiosink")
 
     def test_append_sink(self):
         obj, name = Sink("volume")
         self.failUnless(obj)
         self.failUnlessEqual(name.split("!")[-1].strip(), Sink("")[1])
 
-add(TGStreamerSink)
 
+@skipUnless(Gst, "GStreamer missing")
 class TGstreamerTagList(TestCase):
     def test_parse(self):
         # gst.TagList can't be filled using pyGtk... so use a dict instead
@@ -58,7 +86,6 @@ class TGstreamerTagList(TestCase):
         self.failUnless("bar" in parse_gstreamer_taglist(l))
         self.failUnlessEqual(parse_gstreamer_taglist(l)["bar"], "foo\nfoo2")
 
-
         # date is abstract, so define our own
         # (might work with pygobject now)
         class Foo(object):
@@ -71,12 +98,14 @@ class TGstreamerTagList(TestCase):
         Gst.DateTime = date
 
         l["foo"] = u"äöü"
-        self.failUnless(isinstance(parse_gstreamer_taglist(l)["foo"], unicode))
-        self.failUnlessEqual(parse_gstreamer_taglist(l)["foo"], u"äöü")
+        parsed = parse_gstreamer_taglist(l)
+        self.assertTrue(isinstance(parsed["foo"], unicode))
+        self.assertTrue(u"äöü" in parsed["foo"].split("\n"))
 
         l["foo"] = u"äöü".encode("utf-8")
-        self.failUnless(isinstance(parse_gstreamer_taglist(l)["foo"], unicode))
-        self.failUnlessEqual(parse_gstreamer_taglist(l)["foo"], u"äöü")
+        parsed = parse_gstreamer_taglist(l)
+        self.assertTrue(isinstance(parsed["foo"], unicode))
+        self.assertTrue(u"äöü" in parsed["foo"].split("\n"))
 
         l["bar"] = 1.2
         self.failUnlessEqual(parse_gstreamer_taglist(l)["bar"], 1.2)
@@ -165,5 +194,3 @@ class TGstreamerTagList(TestCase):
 
         # parse_gstreamer_taglist should only return unicode
         self.failIf(sanitize_tags({"foo": "bar"}))
-
-add(TGstreamerTagList)
